@@ -515,8 +515,8 @@ void DrawTriangleWithEffect( int x, int y, const char *techniqueName )
     int viewHeight = Height / 2;
 
     D3D10_VIEWPORT vp;
-    vp.Width    = (float)viewWidth;
-    vp.Height   = (float)viewHeight;
+    vp.Width    = static_cast<UINT>(viewWidth);
+    vp.Height   = static_cast<UINT>(viewHeight);
     vp.MinDepth = 0.0f;
     vp.MaxDepth = 1.0f;
     vp.TopLeftX = x * viewWidth;
