@@ -68,6 +68,7 @@ int main(int argc, char **argv)
   /* Initialize OpenGL entry points. */
   if (glewInit()!=GLEW_OK || !GLEW_VERSION_1_1) {
     fprintf(stderr, "%s: Failed to initialize GLEW. OpenGL 1.1 required.\n", myProgramName);    
+    fflush(stderr);
     exit(1);
   }
 
@@ -93,12 +94,14 @@ static void checkForCgError(const char *situation)
              "Cg compiler output...\n%s",
              myProgramName, situation, string,
              cgGetLastListing(myCgContext));
+      fflush(stderr);
     } else {
       fprintf(stderr,
               "Program: %s\n"
               "Situation: %s\n"
               "Error: %s\n",
               myProgramName, situation, string);
+      fflush(stderr);
     }
     exit(1);
   }
@@ -131,18 +134,21 @@ static void getLayerNamesFromParameterAnnotation(const char *paramName,
   if (!myCgLayerListParam) {
     fprintf(stderr, "%s: no parameter found named %s\n",
       myProgramName, paramName);
+    fflush(stderr);
     exit(1);
   }
   layerListOrderAnn = cgGetNamedParameterAnnotation(myCgLayerListParam, annotationName);
   if (!layerListOrderAnn) {
     fprintf(stderr, "%s: no annotation found named %s\n",
       myProgramName, annotationName);
+    fflush(stderr);
     exit(1);
   }
   layerListOrderStr = cgGetStringAnnotationValue(layerListOrderAnn);
   if (!layerListOrderStr) {
     fprintf(stderr, "%s: no annotation string value for %s\n",
       myProgramName, annotationName);
+    fflush(stderr);
     exit(1);
   }
 
@@ -165,6 +171,7 @@ static void getLayerNamesFromParameterAnnotation(const char *paramName,
       fprintf(stderr,
         "%s: layer parameter instance %s not an effect parameter\n",
         myProgramName, layerName);
+      fflush(stderr);
       exit(1);
     }
     i++;
@@ -194,6 +201,7 @@ static void configLayerUnsizedArray(int layers, int initial)
     if (cgValidateTechnique(myCgTechnique) == CG_FALSE) {
       printf("%s: could not validate %s\n",
         myProgramName, cgGetTechniqueName(myCgTechnique));
+      fflush(stdout);
     }
   }
 }
@@ -219,14 +227,17 @@ static void initCg(void)
   while (myCgTechnique && cgValidateTechnique(myCgTechnique) == CG_FALSE) {
     fprintf(stderr, "%s: Technique %s did not validate.  Skipping.\n",
       myProgramName, cgGetTechniqueName(myCgTechnique));
+    fflush(stderr);
     myCgTechnique = cgGetNextTechnique(myCgTechnique);
   }
   if (myCgTechnique) {
     fprintf(stderr, "%s: Initially using technique %s.\n",
       myProgramName, cgGetTechniqueName(myCgTechnique));
+    fflush(stderr);
   } else {
     fprintf(stderr, "%s: No valid technique\n",
       myProgramName);
+    fflush(stderr);
     exit(1);
   }
   myCgPass = cgGetNamedPass(myCgTechnique, myPassDirections[myDoReverseComposite]);
@@ -237,6 +248,7 @@ static void initCg(void)
     fprintf(stderr,
       "%s: must find parameter with ModelViewProjection semantic\n",
       myProgramName);
+    fflush(stderr);
     exit(1);
   }
   myCgEyePositionParam =
@@ -244,6 +256,7 @@ static void initCg(void)
   if (!myCgEyePositionParam) {
     fprintf(stderr, "%s: must find parameter named EyePosition\n",
       myProgramName);
+    fflush(stderr);
     exit(1);
   }
   myCgLightPositionParam =
@@ -251,6 +264,7 @@ static void initCg(void)
   if (!myCgLightPositionParam) {
     fprintf(stderr, "%s: must find parameter named LightPosition\n",
       myProgramName);
+    fflush(stderr);
     exit(1);
   }
 }
@@ -268,6 +282,7 @@ void selectTechnique(int item)
   } else {
     printf("%s: could not validate %s\n",
       myProgramName, cgGetTechniqueName(newTechnique));
+    fflush(stdout);
   }
 }
 
@@ -279,9 +294,11 @@ static int initTechniqueMenu(void)
 
   technique = cgGetFirstTechnique(myCgEffect);
   while (technique && entry < MAX_TECHNIQUES) {
-    validTechnique[entry] = technique;
-    glutAddMenuEntry(cgGetTechniqueName(technique), entry);
-    entry++;
+    if (cgValidateTechnique(technique)) {
+      validTechnique[entry] = technique;
+      glutAddMenuEntry(cgGetTechniqueName(technique), entry);
+      entry++;
+    }
     technique = cgGetNextTechnique(technique);
   }
   return menu;
@@ -430,6 +447,11 @@ static void outputLayers(void)
       }
       glColor3f(1,1,0);
       output(10, 20+18*i, "bottom layer");
+
+      glColor3f(1,1,0);
+      output(10, myWindowHeight - 16, cgGetTechniqueName(myCgTechnique));
+      glColor3f(1,1,1);
+
     glPopMatrix();
   glMatrixMode(GL_PROJECTION);
   glPopMatrix();
@@ -619,6 +641,7 @@ static void keyboard(unsigned char c, int x, int y)
     }
     break;
   case 'W':
+  case 'w':
     wireframe = !wireframe;
     if (wireframe) {
       glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
